-------------------------------------------------------------------------------
-- Locals                                                                    --
-------------------------------------------------------------------------------

local L = AceLibrary("AceLocale-2.0"):new("ClosetGnomeOhNoes")
local gratuity = AceLibrary("Gratuity-2.0")


local lastItems = {}
local gotNakie

-------------------------------------------------------------------------------
-- Addon declaration                                                         --
-------------------------------------------------------------------------------

ClosetGnomeOhNoes = AceLibrary("AceAddon-2.0"):new("AceConsole-2.0", "AceDB-2.0", "AceEvent-2.0")
ClosetGnomeOhNoes:RegisterDB("ClosetGnomeOhNoesDB")
ClosetGnomeOhNoes:RegisterDefaults("profile", {
	enabled = true,
	health = .03,
})
ClosetGnomeOhNoes:RegisterChatCommand({ "/ohnoes", "/oh"}, {
    type = 'group',  
    handler = ClosetGnomeOhNoes,
    args = {
        percent = {
          name = 'percent',
          type = 'range',
          desc = 'Set the percentage at which Oh Noes! triggers.',
          get = function() return ClosetGnomeOhNoes.db.profile.health end,
          set = function(value) ClosetGnomeOhNoes.db.profile.health = value end,
          min = 0.01,
          max = 1,
          step = 0.01,
          isPercent = true,
        }
      }
    }
  )


-------------------------------------------------------------------------------
-- Initialization                                                            --
-------------------------------------------------------------------------------

function ClosetGnomeOhNoes:OnEnable()
	if not ClosetGnome then return end
	self:RegisterBucketEvent("UNIT_HEALTH", 0.2)
end

-------------------------------------------------------------------------------
-- Events                                                                    --
-------------------------------------------------------------------------------

function ClosetGnomeOhNoes:UNIT_HEALTH(unit)
  if not unit.player then return end
	if not self.db.profile.enabled then return end
	local health = UnitHealth("player") / UnitHealthMax("player")
	if health <= self.db.profile.health and not gotNakie then
	  self:GetNakie()
	elseif health >= self.db.profile.health and gotNakie and GetTime() - gotNakie >= 1 then
	  gotNakie = nil
	  self:NoLongerDying()
	end
end

function ClosetGnomeOhNoes:GetNakie()
  self:Print("OH NOES! unequipping weapons...")
  gotNakie = GetTime()
  if not lastItems["MainHandSlot"] then
    gratuity:SetInventoryItem("player", GetInventorySlotInfo("MainHandSlot"))
    lastItems["MainHandSlot"] = gratuity:GetLine(1)
  end
  if not lastItems["SecondaryHandSlot"] then
    gratuity:SetInventoryItem("player", GetInventorySlotInfo("SecondaryHandSlot"))
    lastItems["SecondaryHandSlot"] = gratuity:GetLine(1)
  end
  if not lastItems["RangedHandSlot"] then
    gratuity:SetInventoryItem("player", GetInventorySlotInfo("RangedSlot"))
    lastItems["RangedSlot"] = gratuity:GetLine(1)
  end
  ClosetGnome:EquipItem("MainHandSlot", false, true)
  ClosetGnome:EquipItem("SecondaryHandSlot", false, true)
  ClosetGnome:EquipItem("RangedSlot", false, true)
end

function ClosetGnomeOhNoes:NoLongerDying()
  self:Print("All better! putting weapons back on.")
	if not lastItems or not self.db.profile.enabled then return end
  ClosetGnome:EquipItem("MainHandSlot",lastItems["MainHandSlot"], true)
  ClosetGnome:EquipItem("MainHandSlot",lastItems["SecondaryHandSlot"], true)
  ClosetGnome:EquipItem("MainHandSlot",lastItems["SecondaryHandSlot"], true)
  lastItems = {}
end
